@@ -823,6 +823,18 @@ def readLinesFile(filename, grab=False):
 def isEmptyFile(filename, grab=False):
     return not any(readLinesFile(filename, grab=grab))
 
+
+def grepFile(filename, regexp, flags=0):
+    """
+    Получить из файла данные по регулярному выражению
+    """
+    data = readFile(filename)
+    match = re.search(regexp, data, flags=flags)
+    if match:
+        return match.group()
+    return ""
+
+
 def readFile(filename, tailbyte=None, headbyte=None, grab=False):
     """
     Прочитать целый файл или вернуть пустую строку.
